iterationtools.iterate_components_and_grace_containers_in_expr
==============================================================

.. autofunction:: abjad.tools.iterationtools.iterate_components_and_grace_containers_in_expr.iterate_components_and_grace_containers_in_expr
   :noindex:
